Quantum Classification for Machine Learning
===========================================

Forge provides the beginnings of quantum machine learning in the form of classification
algorithms for fitting data points to a classification model, and predicting the classification
of further data points in a unified function.

.. autofunction:: qcware.qml.fit_and_predict
